Geometry
========

.. currentmodule:: scarabee

.. autoclass:: scarabee.Vector

.. autoclass:: scarabee.Direction

.. autoclass:: scarabee.EmptyCell

.. autoclass:: scarabee.PinCellType

.. autoclass:: scarabee.SimplePinCell

.. autoclass:: scarabee.PinCell

.. autoclass:: scarabee.BWRCornerType
    :members:

.. autoclass:: scarabee.SimpleBWRCornerPinCell

.. autoclass:: scarabee.BWRCornerPinCell

.. autoclass:: scarabee.Tile
    :members:
    :inherited-members:

.. autoclass:: scarabee.TileIndex
    :members:
    :inherited-members:

.. autoclass:: scarabee.Cartesian2D
